@@ -14,6 +14,9 @@ from .case import TestCase
 from .call import Call
 from .loader import TestLoader
 from .result import TestResult
+from .abstract_base import abstract_base_test
+
+from .exceptions import *
 
 defaultTestLoader = TestLoader
 
